<?php
/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB Taxonomy directory)
 *
 * @category YourThemeOrPlugin
 * @package  Metaboxes
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/jcchavezs/cmb2-taxonomy
 */



 add_filter('cmb2-taxonomy_meta_boxes', 'helix_taxonomy_metaboxes');

/**
 * Define the metabox and field configurations.
 *
 * @param  array $meta_boxes
 * @return array
 */
function helix_taxonomy_metaboxes( array $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = 'helix_met_';

	/**
	 * trainer metabox to demonstrate each field type included
	 */
	$meta_boxes['trainer_metabox'] = array(
		'id'            => 'trainer_metabox',
		'title'         => __( 'Trainer metabox', 'helix' ),
		'object_types'  => array( 'trainer' ), // Taxonomy
		'context'       => 'normal',
		'priority'      => 'high',
		'show_names'    => true, // Show field names on the left
		//'cmb_styles' => false, // false to disable the CMB stylesheet
		'fields'        => array(
			array(
		        'name'       => esc_html__( 'Title', 'helix' ),
		        'desc'       => esc_html__( '(optional). input title page header', 'helix' ),
		        'id'         => $prefix . 'title_page',
		        'type'       => 'text'
		    ),
		    array(
		        'name'       => esc_html__( 'Description', 'helix' ),
		        'desc'       => esc_html__( '(optional). input description page header', 'helix' ),
		        'id'         => $prefix . 'desc_page',
		        'type'       => 'textarea_small'
		    ),
			array(
				'name'       => __( 'Avatar', 'helix' ),
				'desc'       => __( 'Upload an avatar image or enter a URL', 'helix' ),
				'id'         => $prefix . 'trainer_avatar',
				'type'       => 'file'
			),
			// array(
			// 	'name'       => __( 'Profile Detail', 'helix' ),
			// 	'id'         => $prefix . 'trainer_body',
			// 	'type'       => 'wysiwyg',
			// 	'options' 	 => array( 'textarea_rows' => 5)
			// ),
			array(
				'name'       => __( 'Job', 'helix' ),
				'id'         => $prefix . 'trainer_job',
				'type'       => 'text'
			),
			array(
				'name'       => __( 'Position', 'helix' ),
				'id'         => $prefix . 'trainer_position',
				'type'       => 'text'
			),
			array(
				'name'       => __( 'Experience', 'helix' ),
				'id'         => $prefix . 'trainer_experience',
				'type'       => 'text'
			),
			array(
				'name'       => __( 'Email', 'helix' ),
				'id'         => $prefix . 'trainer_email',
				'type'       => 'text_email'
			),
			array(
				'name'       => __( 'Facebook', 'helix' ),
				'id'         => $prefix . 'trainer_facebook',
				'type'       => 'text_url'
			),
			array(
				'name'       => __( 'Twitter', 'helix' ),
				'id'         => $prefix . 'trainer_twitter',
				'type'       => 'text_url'
			),
			array(
				'name'       => __( 'Instagram', 'helix' ),
				'id'         => $prefix . 'trainer_instagram',
				'type'       => 'text_url'
			),
			array(
				'name'       => __( 'Youtube', 'helix' ),
				'id'         => $prefix . 'trainer_youtube',
				'type'       => 'text_url'
			),
			array(
				'name'       => __( 'Google+', 'helix' ),
				'id'         => $prefix . 'trainer_google',
				'type'       => 'text_url'
			),
		),
	);
	

	 /**
	 * room metabox to demonstrate each field type included
	 */
	 $meta_boxes['room_metabox'] = array(
		'id'            => 'room_metabox',
		'title'         => __( 'Room metabox', 'helix' ),
		'object_types'  => array( 'room' ), // Taxonomy
		'context'       => 'normal',
		'priority'      => 'high',
		'show_names'    => true, // Show field names on the left
		//'cmb_styles' => false, // false to disable the CMB stylesheet
		'fields'        => array(
			array(
				'name'       => __( 'Position', 'helix' ),
				'id'         => $prefix . 'room_position',
				'type'       => 'text'
			),
			array(
				'name'       => __( 'Floors', 'helix' ),
				'id'         => $prefix . 'room_floors',
				'type'       => 'text'
			)
		),
	);
	return $meta_boxes;
}
