<?php
/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB2 directory)
 *
 * Be sure to replace all instances of 'yourprefix_' with your project's prefix.
 * http://nacin.com/2010/05/11/in-wordpress-prefix-everything/
 *
 * @category YourThemeOrPlugin
 * @package  Demo_CMB2
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */
class PW_CMB2_Field_Google_Maps {
    /**
     * Current version number
     */
    const VERSION = '2.1.1';
    /**
     * Initialize the plugin by hooking into CMB2
     */
    public function __construct() {
        add_filter( 'cmb2_render_pw_map', array( $this, 'render_pw_map' ), 10, 5 );
        add_filter( 'cmb2_sanitize_pw_map', array( $this, 'sanitize_pw_map' ), 10, 4 );
    }
    /**
     * Render field
     */
    public function render_pw_map( $field, $field_escaped_value, $field_object_id, $field_object_type, $field_type_object ) {
        $this->setup_admin_scripts();
        echo '<input type="text" class="large-text pw-map-search" id="' . $field->args( 'id' ) . '" />';
        echo '<div class="pw-map"></div>';
        $field_type_object->_desc( true, true );
        echo ''.$field_type_object->input( array(
            'type'       => 'text',
            'name'       => $field->args('_name') . '[latitude]',
            'value'      => isset( $field_escaped_value['latitude'] ) ? $field_escaped_value['latitude'] : '',
            'class'      => 'pw-map-latitude',
            'desc'       => '<span class="desc">'.esc_html__( 'Position:Latitude', 'helix' ).'</span>',
        ) );
        echo ''.$field_type_object->input( array(
            'type'       => 'text',
            'name'       => $field->args('_name') . '[longitude]',
            'value'      => isset( $field_escaped_value['longitude'] ) ? $field_escaped_value['longitude'] : '',
            'class'      => 'pw-map-longitude',
            'desc'       => '<span class="desc">'.esc_html__( 'Position:Longitude', 'helix' ).'</span>',
        ) );
    }
    /**
     * Optionally save the latitude/longitude values into two custom fields
     */
    public function sanitize_pw_map( $override_value, $value, $object_id, $field_args ) {
        if ( isset( $field_args['split_values'] ) && $field_args['split_values'] ) {
            if ( ! empty( $value['latitude'] ) ) {
                update_post_meta( $object_id, $field_args['id'] . '_latitude', $value['latitude'] );
            }
            if ( ! empty( $value['longitude'] ) ) {
                update_post_meta( $object_id, $field_args['id'] . '_longitude', $value['longitude'] );
            }
        }
        return $value;
    }
    /**
     * Enqueue scripts and styles
     */
    public function setup_admin_scripts() {
        wp_register_script( 'pw-google-maps-api', '//maps.googleapis.com/maps/api/js?v=3&key=AIzaSyDQPDIG38N98oNsnP384k6_Ur18bh1LeiE&sensor=false&libraries=places', null, null );
        wp_enqueue_script( 'pw-google-maps', OVA_THEME_URI.'/js/script.js', array( 'pw-google-maps-api' ), self::VERSION );
        wp_enqueue_style( 'pw-google-maps', OVA_THEME_URI.'/css/theme.css', array(), self::VERSION );
    }
}
$pw_cmb2_field_google_maps = new PW_CMB2_Field_Google_Maps();

add_action( 'cmb2_init', 'helix_metaboxes');
function helix_metaboxes() {

    // Start with an underscore to hide fields from custom fields list
    $prefix = 'helix_met_';

    /* Page Settings ***************************************************************************/
    /* ************************************************************************************/
    $page_settings = new_cmb2_box( array(
        'id'            => 'page_heading_settings',
        'title'         => esc_html__( 'Page Heading Settings', 'helix' ),
        'object_types'  => array( 'page'), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true
    ));

    // Display title of page
    $page_settings->add_field( array(
        'name'       => esc_html__( 'Title', 'helix' ),
        'desc'       => esc_html__( '(optional). input title page header', 'helix' ),
        'id'         => $prefix . 'title_page',
        'type'       => 'text'
    ));
    $page_settings->add_field( array(
        'name'       => esc_html__( 'Description', 'helix' ),
        'desc'       => esc_html__( '(optional). input description page header', 'helix' ),
        'id'         => $prefix . 'desc_page',
        'type'       => 'textarea_small'
    ));
    $page_settings->add_field( array(
            'name'       => esc_html__( 'Class Layout display', 'helix' ),
            'desc'       => esc_html__( '(optional).Only allow use page class template , show layout template', 'helix' ),
            'id'         => $prefix . 'class_layout',
            'type'             => 'select',
            'show_option_none' => false,
            'options'          => array(
                'global'   => esc_html__('Global in customizer', 'helix' ),
                'list'   => esc_html__('List', 'helix' ),
                'grid' => esc_html__( 'Grid', 'helix' )
                
            ),
            'default' => 'global'
        ) );
    /* Post Settings *********************************************************************************/
    /* *******************************************************************************/
    $post_settings = new_cmb2_box( array(
        'id'            => 'post_video',
        'title'         => esc_html__( 'Post Settings', 'helix' ),
        'object_types'  => array( 'post'), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ) );
      // Display title of page
    $post_settings->add_field( array(
        'name'       => esc_html__( 'Title', 'helix' ),
        'desc'       => esc_html__( '(optional). input title page header', 'helix' ),
        'id'         => $prefix . 'title_page',
        'type'       => 'text'
    ));
    $post_settings->add_field( array(
        'name'       => esc_html__( 'Description', 'helix' ),
        'desc'       => esc_html__( '(optional). input description page header', 'helix' ),
        'id'         => $prefix . 'desc_page',
        'type'       => 'textarea_small'
    ));


    $classes_settings = new_cmb2_box( array(
        'id'            => 'classes_settings',
        'title'         => esc_html__( 'Classes Settings', 'helix' ),
        'object_types'  => array( 'class'), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ));
    // Display title of page
    $classes_settings->add_field( array(
        'name'       => esc_html__( 'Title', 'helix' ),
        'desc'       => esc_html__( '(optional). input title page header', 'helix' ),
        'id'         => $prefix . 'title_page',
        'type'       => 'text'
    ));
    $classes_settings->add_field( array(
        'name'       => esc_html__( 'Description', 'helix' ),
        'desc'       => esc_html__( '(optional). input description page header', 'helix' ),
        'id'         => $prefix . 'desc_page',
        'type'       => 'textarea_small'
    ));
    $classes_settings->add_field( array(
        'name'    => esc_html__( 'Date start', 'helix' ),
        'desc'    => esc_html__( 'Date start class to course', 'helix' ),
        'default' => '',
        'id'      => $prefix . 'class_date_start',
        'type'    => 'text_date',
        'date_format' => str_replace( 'F', 'M', get_option( 'date_format' ) )

    ) );

    $classes_settings->add_field( array(
        'name'    => esc_html__( 'Date End', 'helix' ),
        'desc'    => esc_html__( 'End Date class to course', 'helix' ),
        'default' => '',
        'id'      => $prefix . 'class_date_end',
        'type'    => 'text_date',
        'date_format' => str_replace( 'F', 'M', get_option( 'date_format' ) )
        
    ) );
    $classes_settings->add_field( array(
        'name'    => esc_html__( 'Time start', 'helix' ),
        'desc'    => esc_html__( 'Time start in class', 'helix' ),
        'default' => '',
        'id'      => $prefix . 'class_time_start',
        'type'    => 'text_time'
    ) );
    $classes_settings->add_field( array(
        'name'    => esc_html__( 'End time', 'helix' ),
        'desc'    => esc_html__( 'End time in class', 'helix' ),
        'default' => '',
        'id'      => $prefix . 'class_time_end',
        'type'    => 'text_time'
    ) );
    $classes_settings->add_field( array(
        'name'    => esc_html__( 'Days learn', 'helix' ),
        'desc'    =>  esc_html__( 'Day in week', 'helix' ),
        'default' => '',
        'id'      => $prefix . 'class_days',
        'type' => 'multicheck',
        'options' => array(
            'Monday' => __( 'Mon', 'helix' ),
            'Tuesday' => __( 'Tue', 'helix' ),
            'Wednesday' => __( 'Wed', 'helix' ),
            'Thursday' => __( 'Thu', 'helix' ),
            'Friday' => __( 'Fri', 'helix' ),
            'Saturday' => __( 'Sat', 'helix'),
            'Sunday' => __( 'Sun', 'helix' )
        ),
    ) );
    $classes_settings->add_field( array(
        'name'    => esc_html__( 'Number member', 'helix' ),
        'desc'    => esc_html__( 'Number member in class', 'helix' ),
        'default' => '',
        'id'      => $prefix . 'class_number_member',
        'type'    => 'text'
    ) );
     $classes_settings->add_field( array(
        'name'    => esc_html__( 'Register in class', 'helix' ),
        'desc'    => esc_html__( 'Link to resgister in class', 'helix' ),
        'default' => '#',
        'id'      => $prefix . 'class_link_resgister',
        'type'    => 'text_url'
    ) );
    // Video or Audio
    $classes_settings->add_field( array(
        'name'       => esc_html__( 'Link audio or video', 'helix' ),
        'desc'       => esc_html__( 'Insert link audio or video use for video/audio class', 'helix' ),
        'id'         => $prefix . 'class_embed_media',
        'type'             => 'oembed'
    ) );

    // Gallery image
    $classes_settings->add_field( array(
        'name'       => esc_html__( 'Gallery image', 'helix' ),
        'desc'       => esc_html__( 'image in gallery class', 'helix' ),
        'id'         => $prefix . 'class_file_list',
        'type'       => 'file_list'
    ));
    // Color schedule
    $classes_settings->add_field( array(
        'name'       => esc_html__( 'Color schedule class', 'helix' ),
        'desc'       => esc_html__( 'Option: Color display schedule class', 'helix' ),
        'id'         => $prefix . 'class_color',
        'type'       => 'colorpicker'
    ));


    $events_settings = new_cmb2_box( array(
        'id'            => 'events_settings',
        'title'         => esc_html__( 'Events Settings', 'helix' ),
        'object_types'  => array( 'events'), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
        'show_names'    => true, // Show field names on the left
    ));
    $events_settings->add_field( array(
        'name'       => esc_html__( 'From date', 'helix' ),
        'desc'       => esc_html__( 'input date start event', 'helix' ),
        'id'         => $prefix . 'event_fromdate',
        'type'       => 'text_date'
    ));
    $events_settings->add_field( array(
        'name'       => esc_html__( 'To date', 'helix' ),
        'desc'       => esc_html__( 'input date end event', 'helix' ),
        'id'         => $prefix . 'event_todate',
        'type'       => 'text_date'
    ));
    // $events_settings->add_field( array(
    //     'name'    => esc_html__( 'Price', 'helix' ),
    //     'desc'    => esc_html__( 'Input price event ', 'helix' ),
    //     'default' => '',
    //     'id'      => $prefix . 'event_price',
    //     'type'    => 'text'
    // ));
    $events_settings->add_field( array(
        'name'    => esc_html__( 'Map:Position', 'helix' ),
        'desc'    => esc_html__( 'Input key search location and drag the marker to set exact location ', 'helix' ),
        'default' => '',
        'id'      => $prefix . 'map',
        'type'    => 'pw_map'
    ));
    $events_settings->add_field( array(
        'name'    => esc_html__( 'Location: Address', 'helix' ),
        'desc'    => esc_html__( 'Input address from event', 'helix' ),
        'default' => '',
        'id'      => $prefix . 'event_address',
        'type'    => 'text'
    ) );
    $events_settings->add_field( array(
        'name'    => esc_html__( 'Location: Phone', 'helix' ),
        'desc'    => esc_html__( 'Input Phone number', 'helix' ),
        'default' => '',
        'id'      => $prefix . 'event_phone_number',
        'type'    => 'text'
    ) );
    $group_event_schedule = $events_settings->add_field( array(
        'id'          => $prefix .'group_event_schedule',
        'type'        => 'group',
        'description' => __( 'Events schedule', 'helix' ),
        // 'repeatable'  => false, // use false if you want non-repeatable group
        'options'     => array(
            'group_title'   => __( 'Event schedule Session {#}', 'helix' ), // since version 1.1.4, {#} gets replaced by row number
            'add_button'    => __( 'Add event schedule', 'helix' ),
            'remove_button' => __( 'Remove event schedule', 'helix' ),
            'sortable'      => true, // beta
            // 'closed'     => true, // true to have the groups closed by default
        ),
    ));
    $events_settings->add_group_field( $group_event_schedule, array(
    'name' => 'Session',
    'id'   =>  $prefix .'event_session',
    'type' => 'text',
    // 'repeatable' => true, // Repeatable fields are supported w/in repeatable groups (for most types)
    ));
    $events_settings->add_group_field( $group_event_schedule, array(
    'name' => 'Time',
    'id'   => $prefix .'event_time',
    'type' => 'text_time',
    // 'repeatable' => true, // Repeatable fields are supported w/in repeatable groups (for most types)
    ));
   
}

